==> dxde_1.40.6-1.tar.gz: BUILD/src/model/data/firma.h <==
/***************************************************************
 * Name:      firma.h
 * Author:    David Vachulka (arch_dvx@users.sourceforge.net)
 * Copyright: 2014
 * License:   GPL3
 **************************************************************/

#ifndef FIRMA_H
#define FIRMA_H

#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif

class Firma {
public:
    Firma() : m_nazev(wxEmptyString), m_platce(false), m_pausal(false), m_adresaid(-1), m_eet(false) {}
    Firma(const wxString &nazev, const wxString &ic, const wxString &dic, const wxString &registrace, bool platce, bool pausal,
          const wxString &telefon, const wxString &email, const wxString &www, const wxString &logo, const wxString &razitko,
          int adresaid, bool eet);

    bool isValid() const;
    wxString nazev() const;
    void setNazev(const wxString &nazev);
    wxString ic() const;
    void setIc(const wxString &ic);
    wxString dic() const;
    void setDic(const wxString &dic);
    wxString registrace() const;
    void setRegistrace(const wxString &registrace);
    bool platce() const;
    void setPlatce(bool platce);
    wxString telefon() const;
    void setTelefon(const wxString &telefon);
    wxString email() const;
    void setEmail(const wxString &email);
    wxString www() const;
    void setWww(const wxString &www);
    wxString logo() const;
    void setLogo(const wxString &logo);
    wxString razitko() const;
    void setRazitko(const wxString &razitko);
    int adresaid() const;
    void setAdresaid(int adresaid);
    bool pausal() const;
    void setPausal(bool pausal);
    bool eet() const;
    void setEet(bool eet);
private:
    wxString m_nazev;
    wxString m_ic;
    wxString m_dic;
    wxString m_registrace;
    bool m_platce;
    bool m_pausal;
    wxString m_telefon;
    wxString m_email;
    wxString m_www;
    wxString m_logo;
    wxString m_razitko;
    int m_adresaid;
    bool m_eet;
};

#endif  /* FIRMA_H */

==> dxde_1.40.12-1.tar.gz: BUILD/src/model/data/firma.h <==
/***************************************************************
 * Name:      firma.h
 * Author:    David Vachulka (archdvx@dxsolutions.org)
 * Copyright: 2014
 * License:   GPL3
 **************************************************************/

#ifndef FIRMA_H
#define FIRMA_H

#ifndef WX_PRECOMP
    #include <wx/wx.h>
#endif

class Firma {
public:
    Firma() : m_nazev(wxEmptyString), m_platce(false), m_pausal(false), m_adresaid(-1) {}
    Firma(const wxString &nazev, const wxString &ic, const wxString &dic, const wxString &registrace, bool platce, bool pausal,
          const wxString &telefon, const wxString &email, const wxString &www, const wxString &logo, const wxString &razitko,
          int adresaid);

    bool isValid() const;
    wxString nazev() const;
    void setNazev(const wxString &nazev);
    wxString ic() const;
    void setIc(const wxString &ic);
    wxString dic() const;
    void setDic(const wxString &dic);
    wxString registrace() const;
    void setRegistrace(const wxString &registrace);
    bool platce() const;
    void setPlatce(bool platce);
    wxString telefon() const;
    void setTelefon(const wxString &telefon);
    wxString email() const;
    void setEmail(const wxString &email);
    wxString www() const;
    void setWww(const wxString &www);
    wxString logo() const;
    void setLogo(const wxString &logo);
    wxString razitko() const;
    void setRazitko(const wxString &razitko);
    int adresaid() const;
    void setAdresaid(int adresaid);
    bool pausal() const;
    void setPausal(bool pausal);
private:
    wxString m_nazev;
    wxString m_ic;
    wxString m_dic;
    wxString m_registrace;
    bool m_platce;
    bool m_pausal;
    wxString m_telefon;
    wxString m_email;
    wxString m_www;
    wxString m_logo;
    wxString m_razitko;
    int m_adresaid;
};

#endif  /* FIRMA_H */
